# profile — features


本 domain 下的所有功能：

- ✅ [FEAT-005 profile-set](./FEAT-005-profile-set.md) — done
- ✅ [FEAT-006 profile-show](./FEAT-006-profile-show.md) — done
- ✅ [FEAT-007 profile-clear](./FEAT-007-profile-clear.md) — done
- 🚧 [FEAT-008 avatar](./FEAT-008-avatar.md) — in_progress
- 📋 [FEAT-009 album](./FEAT-009-album.md) — planned
